==> sdk-web-components-11.0.1.tgz: package/dist-vite/esm/bp-sdk-errors_2.entry.js <==
import { r as registerInstance, h } from './index-77a9c9e7.js';
import { M, r as ye } from './index.esm.min-9889e78b.js';

const bpSdkErrorsCss = "";
const BpSdkErrorsStyle0 = bpSdkErrorsCss;

const BpSdkErrors = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.answerId = undefined;
        this.questionId = undefined;
        this.min = undefined;
        this.minDate = undefined;
        this.max = undefined;
        this.maxDate = undefined;
        this.fieldType = undefined;
        this.pattern = undefined;
        this.errors = [];
        this.errorText = undefined;
        this.errorMessages = undefined;
        this.useExternal = false;
    }
    transformError(error) {
        switch (error) {
            case M.MaximumValue:
            case M.MinimumValue:
                if (ye.includes(this.fieldType)) {
                    return this.errorMessages.value(this.min, this.max);
                }
                else {
                    return this.errorMessages.length(this.min, this.max);
                }
            case M.MinimumDate:
            case M.MaximumDate:
                return this.errorMessages.date(this.minDate, this.maxDate);
            case M.Required:
                return this.errorMessages.required();
            case M.Pattern:
                return this.errorMessages.pattern();
        }
        return error;
    }
    resetState() { }
    connectedCallback() {
        this.resetState();
    }
    componentWillLoad() {
        this.useExternal = !!customElements.get('bp-sdk-external-errors');
        customElements.whenDefined('bp-sdk-external-errors').then(() => {
            this.useExternal = true;
        });
    }
    render() {
        return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
    }
    renderExternal() {
        return (h("bp-sdk-external-errors", { answerId: this.answerId, errorMessages: this.errorMessages, errors: this.errors, errorText: this.errorText, fieldType: this.fieldType, maxDate: this.maxDate, max: this.max, minDate: this.minDate, min: this.min, pattern: this.pattern, questionId: this.questionId }));
    }
    renderInternal() {
        return (h("div", { class: "bp-sdk-errors__container" }, this.errorText && (h("span", { "aria-live": "polite", id: `bp-sdk-error-${this.answerId}-text`, class: `bp-sdk-errors-text bp-sdk-errors-text-${this.answerId}` }, this.errorText)), !this.errorText && (h("ul", { class: "bp-sdk-errors__list" }, this.errors.map((error) => (h("li", { "aria-live": "polite", id: `bp-sdk-errors__${this.answerId}-${error}`, class: `bp-sdk-errors__list-item bp-sdk-errors__list-item-${this.answerId}` }, this.transformError(error))))))));
    }
};
BpSdkErrors.style = BpSdkErrorsStyle0;

const bpSdkErrorsContainerCss = "";
const BpSdkErrorsContainerStyle0 = bpSdkErrorsContainerCss;

const BpSdkErrorsContainer = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.answerId = undefined;
        this.questionId = undefined;
        this.min = undefined;
        this.minDate = undefined;
        this.max = undefined;
        this.maxDate = undefined;
        this.fieldType = undefined;
        this.pattern = undefined;
        this.errors = [];
        this.errorText = undefined;
        this.errorMessages = BpSdkErrorsContainer.DEFAULT_ERROR_MESSAGES;
        this.useExternal = false;
    }
    resetState() { }
    connectedCallback() {
        this.resetState();
    }
    componentWillLoad() {
        this.useExternal = !!customElements.get('bp-sdk-external-errors-container');
        customElements.whenDefined('bp-sdk-external-errors-container').then(() => {
            this.useExternal = true;
        });
    }
    render() {
        return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
    }
    renderExternal() {
        return (h("bp-sdk-external-errors-container", { answerId: this.answerId, errorText: this.errorText, errorMessages: this.errorMessages, errors: this.errors, fieldType: this.fieldType, maxDate: this.maxDate, max: this.max, minDate: this.minDate, min: this.min, pattern: this.pattern, questionId: this.questionId }));
    }
    renderInternal() {
        return (h("bp-sdk-errors", { answerId: this.answerId, questionId: this.questionId, fieldType: this.fieldType, min: this.min, max: this.max, minDate: this.minDate, maxDate: this.maxDate, pattern: this.pattern, errorMessages: this.errorMessages, errors: this.errors, errorText: this.errorText }));
    }
};
BpSdkErrorsContainer.DEFAULT_ERROR_MESSAGES = {
    value: (min, max) => {
        if (min != null && max != null) {
            return `Please select a value in range of ${min} to ${max}.`;
        }
        else if (min != null) {
            return `Please select a value of ${min} or larger.`;
        }
        else {
            return `Please select a value of ${min} or smaller.`;
        }
    },
    length: (min, max) => {
        if (min != null && min === max) {
            return `Please rephrase your answer in ${min} characters.`;
        }
        else if (min != null && max != null) {
            return `Please rephrase your answer in ${min}-${max} characters.`;
        }
        else if (min != null) {
            return `Please rephrase your answer in more than ${min} characters.`;
        }
        else {
            return `Please rephrase your answer in less than ${max} characters.`;
        }
    },
    date: (min, max) => {
        if (min != null && max != null) {
            const range = min === max ? `of ${min}` : `between ${min} and ${max}`;
            return `Please select a date ${range}.`;
        }
        else if (min != null) {
            return `Please select a date after ${min}.`;
        }
        else {
            return `Please select a date before ${max}.`;
        }
    },
    required: () => 'An answer is required for this question.',
    pattern: () => 'Input does not look correct',
};
BpSdkErrorsContainer.style = BpSdkErrorsContainerStyle0;

export { BpSdkErrors as bp_sdk_errors, BpSdkErrorsContainer as bp_sdk_errors_container };

==> sdk-web-components-12.0.0.tgz: package/dist-vite/esm/bp-sdk-errors_2.entry.js <==
import { r as registerInstance, h } from './index-77a9c9e7.js';
import { y as ee, G as pn } from './index.esm-78425ae1.js';

const bpSdkErrorsCss = "";
const BpSdkErrorsStyle0 = bpSdkErrorsCss;

const BpSdkErrors = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.answerId = undefined;
        this.questionId = undefined;
        this.min = undefined;
        this.minDate = undefined;
        this.max = undefined;
        this.maxDate = undefined;
        this.fieldType = undefined;
        this.pattern = undefined;
        this.errors = [];
        this.errorText = undefined;
        this.errorMessages = undefined;
        this.useExternal = false;
    }
    transformError(error) {
        switch (error) {
            case ee.MaximumValue:
            case ee.MinimumValue:
                if (pn.includes(this.fieldType)) {
                    return this.errorMessages.value(this.min, this.max);
                }
                else {
                    return this.errorMessages.length(this.min, this.max);
                }
            case ee.MinimumDate:
            case ee.MaximumDate:
                return this.errorMessages.date(this.minDate, this.maxDate);
            case ee.Required:
                return this.errorMessages.required();
            case ee.Pattern:
                return this.errorMessages.pattern();
        }
        return error;
    }
    resetState() { }
    connectedCallback() {
        this.resetState();
    }
    componentWillLoad() {
        this.useExternal = !!customElements.get('bp-sdk-external-errors');
        customElements.whenDefined('bp-sdk-external-errors').then(() => {
            this.useExternal = true;
        });
    }
    render() {
        return [
            this.useExternal && this.renderExternal(),
            !this.useExternal && this.renderInternal(),
        ];
    }
    renderExternal() {
        return (h("bp-sdk-external-errors", { answerId: this.answerId, errorMessages: this.errorMessages, errors: this.errors, errorText: this.errorText, fieldType: this.fieldType, maxDate: this.maxDate, max: this.max, minDate: this.minDate, min: this.min, pattern: this.pattern, questionId: this.questionId }));
    }
    renderInternal() {
        return (h("div", { class: "bp-sdk-errors__container" }, this.errorText && (h("span", { "aria-live": "polite", id: `bp-sdk-error-${this.answerId}-text`, class: `bp-sdk-errors-text bp-sdk-errors-text-${this.answerId}` }, this.errorText)), !this.errorText && (h("ul", { class: "bp-sdk-errors__list" }, this.errors.map((error) => (h("li", { "aria-live": "polite", id: `bp-sdk-errors__${this.answerId}-${error}`, class: `bp-sdk-errors__list-item bp-sdk-errors__list-item-${this.answerId}` }, this.transformError(error))))))));
    }
};
BpSdkErrors.style = BpSdkErrorsStyle0;

const bpSdkErrorsContainerCss = "";
const BpSdkErrorsContainerStyle0 = bpSdkErrorsContainerCss;

const BpSdkErrorsContainer = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.answerId = undefined;
        this.questionId = undefined;
        this.min = undefined;
        this.minDate = undefined;
        this.max = undefined;
        this.maxDate = undefined;
        this.fieldType = undefined;
        this.pattern = undefined;
        this.errors = [];
        this.errorText = undefined;
        this.errorMessages = BpSdkErrorsContainer.DEFAULT_ERROR_MESSAGES;
        this.useExternal = false;
    }
    resetState() { }
    connectedCallback() {
        this.resetState();
    }
    componentWillLoad() {
        this.useExternal = !!customElements.get('bp-sdk-external-errors-container');
        customElements.whenDefined('bp-sdk-external-errors-container').then(() => {
            this.useExternal = true;
        });
    }
    render() {
        return [
            this.useExternal && this.renderExternal(),
            !this.useExternal && this.renderInternal(),
        ];
    }
    renderExternal() {
        return (h("bp-sdk-external-errors-container", { answerId: this.answerId, errorText: this.errorText, errorMessages: this.errorMessages, errors: this.errors, fieldType: this.fieldType, maxDate: this.maxDate, max: this.max, minDate: this.minDate, min: this.min, pattern: this.pattern, questionId: this.questionId }));
    }
    renderInternal() {
        return (h("bp-sdk-errors", { answerId: this.answerId, questionId: this.questionId, fieldType: this.fieldType, min: this.min, max: this.max, minDate: this.minDate, maxDate: this.maxDate, pattern: this.pattern, errorMessages: this.errorMessages, errors: this.errors, errorText: this.errorText }));
    }
};
BpSdkErrorsContainer.DEFAULT_ERROR_MESSAGES = {
    value: (min, max) => {
        if (min != null && max != null) {
            return `Please select a value in range of ${min} to ${max}.`;
        }
        else if (min != null) {
            return `Please select a value of ${min} or larger.`;
        }
        else {
            return `Please select a value of ${min} or smaller.`;
        }
    },
    length: (min, max) => {
        if (min != null && min === max) {
            return `Please rephrase your answer in ${min} characters.`;
        }
        else if (min != null && max != null) {
            return `Please rephrase your answer in ${min}-${max} characters.`;
        }
        else if (min != null) {
            return `Please rephrase your answer in more than ${min} characters.`;
        }
        else {
            return `Please rephrase your answer in less than ${max} characters.`;
        }
    },
    date: (min, max) => {
        if (min != null && max != null) {
            const range = min === max ? `of ${min}` : `between ${min} and ${max}`;
            return `Please select a date ${range}.`;
        }
        else if (min != null) {
            return `Please select a date after ${min}.`;
        }
        else {
            return `Please select a date before ${max}.`;
        }
    },
    required: () => 'An answer is required for this question.',
    pattern: () => 'Input does not look correct',
};
BpSdkErrorsContainer.style = BpSdkErrorsContainerStyle0;

export { BpSdkErrors as bp_sdk_errors, BpSdkErrorsContainer as bp_sdk_errors_container };
